//If 'RadiosityOn' is turned on, it will add more realism but takes a lot longer to render. You can decrease the 
//	'count' and 'nearest_count' values to get a faster rendering 

#version 3.7;

#declare RadiosityOn = true;
#declare SkyOn = true;

#declare PlaceTrees = true;
#declare DebugCam = false;

#declare CameraDirection = 400;

#declare SceneWidth = 100;
#declare SceneHeight = 80;
#declare SceneDepth = 90;

global_settings{ 
	assumed_gamma 1.0 
	#local P_start = 64 / image_width;
	#local P_end_final = 2 / image_width;

	#if( RadiosityOn )
		radiosity{
				pretrace_start P_start
				pretrace_end   P_end_final
				error_bound 0.25
				minimum_reuse 0.015
				nearest_count 9
				count 800
				recursion_limit 1
				always_sample off
				low_error_factor 0.7
				gray_threshold 0.6
				brightness 1
				normal on
				media on
				adc_bailout 0.01 / 2
		}
	#end
}

#if( SkyOn )
	sphere{ 0, 1 
		pigment{ color srgb < 143 / 255, 195 / 255, 251 / 255 > }
		finish{ diffuse 0 emission 2 }
		scale 4000
		hollow on 
		no_shadow
		no_image
		no_reflection
	}
#end

#include "includes/colorsAnt.inc"
#include "includes/texturesAnt.inc"

#include "includes/ground.inc"
#include "includes/placeTrees.inc"
#include "includes/backgroundObjects.inc"

#if( DebugCam )
    camera{
        location < SceneWidth, SceneHeight, -CameraDirection > * < 0.1, 1, 0.1 >
        look_at < 0, SceneHeight / 2, CameraDirection / 2 > 
    }
#else
    camera{
        orthographic
        location < 0, SceneHeight / 2, -CameraDirection >
        look_at < 0, SceneHeight / 2, 0 >
        sky y
        direction CameraDirection * z
        up SceneHeight * y
        right SceneWidth * x  
    }
#end

light_source{ < 0, 8, -8 > * 400 color srgb 1 }

object{ WholeGround }

PlaceTreesMac()
