#include "woods.inc"

#declare ColorBrightness = 2;
#declare DarkTrunkColor = color srgb < 52 / 255 * ColorBrightness, 38 / 255 * ColorBrightness, 41 / 255 * ColorBrightness >;
#declare TrunkMid1Color = color srgb <114 / 255, 95 / 255, 81 / 255 >;
//#declare C_tronc_mid2 = color srgb <118 / 255, 93 / 255, 71 / 255 >;                                   
#declare TrunkMid2Color = color srgb <118 / 255, 93 / 255, 71 / 255 >;                                   
#declare TrunkWhiteColor = color srgb < 201 / 255, 198 / 255, 201 / 255 >;

#ifndef( WoodLogLength )
	#declare WoodLogLength = 6;
#end

#ifndef( StereLength )
	#declare StereLength = 6;
#end

#declare WoodHolderColor = color srgb < 123 / 255, 83 / 255, 51 / 255 >;

#declare TrunkTexture1 = texture{pigment {wrinkles frequency 4 color_map {
											[0.0  DarkTrunkColor ]
											[0.8 DarkTrunkColor ]
											[0.99 TrunkWhiteColor ]
											[1.0 TrunkWhiteColor ]
											}
										}
                         finish{ specular 0.2 roughness 0.1 }
                        }
#declare TrunkTexture2 = texture{ pigment{ wrinkles color_map {
										[0.0 DarkTrunkColor]
										[0.8 DarkTrunkColor]
										[0.99 TrunkWhiteColor]
										[1.0 TrunkWhiteColor ]
									}
							}
							finish {specular 0.2 roughness 0.1}
						}

#declare TrunkFunction = function{ pigment{
										radial frequency 16 
										warp{turbulence <0.4,0.2,0.4>}
										}
							}

#declare WoodTrunkDisc = 
disc{ < 0, 0, 0 >  < 0, 1, 0 >, 1 texture{ pigment{ wood color_map{
												[0.0 TrunkMid1Color]
												[0.5 TrunkWhiteColor]
												[1.0 TrunkMid1Color]
												}
											rotate -90*x
											scale <0.2,1,0.2>
											warp {turbulence 0.1}
												}
											finish {specular 0.1 roughness 0.1}
										}    
}

#declare TrunkObject = union{
						isosurface{
									function{pow(x,2) + pow(z,2) - TrunkFunction(x, y, z).gray-4}
									threshold 0
									contained_by {box {<-2.6,0,-2.6> <2.6,3,2.6>}}
									max_gradient 20
									accuracy 0.001
									texture{ TrunkTexture1 }
                                    }
                         object{ WoodTrunkDisc scale <2,1,2> translate 3.0001*y}                                                      
                       }

#declare WoodLog = union{
								isosurface{
								function{pow(x,2) + pow(z,2) -0.2 * TrunkFunction(x,y,z).gray - pow(0.4,2)}
								threshold 0
								contained_by{ box { < -0.6, 0, -0.6 > < 0.6, WoodLogLength, 0.6 > } }
								max_gradient 10
								accuracy 0.001
								texture{ TrunkTexture2 }
							}
							object{ WoodTrunkDisc scale 0.4 translate -0.0001*y}
							object{ WoodTrunkDisc scale 0.4 translate ( WoodLogLength + 0.0001 ) * y }
							rotate 90 * x
						}

#declare LogDelta = 0.35;
#declare LogYPlace = sqrt( 3 ) * LogDelta;

#declare WoodStereSeed = seed( 123 );

#macro MakeBucheRow( IsCentered, YPosition)
	#if( IsCentered )
		#for( It, -StereLength, StereLength, 2 )
			object{ WoodLog rotate rand(WoodStereSeed) * 360 * z translate < It, YPosition, 0 > }
		#end
	#else
		#for( It, -StereLength +1, StereLength - 1, 2 )
			object{ WoodLog rotate rand(WoodStereSeed) * 360 * z translate < It, YPosition, 0 > }
		#end
	#end
#end

#declare WoodBarrier =
cylinder{ < 0, 0, 0 >,< 0, 5, 0 >, 0.16 pigment{ WoodHolderColor } }

#declare WoodStere =
union{
	MakeBucheRow( true, 0 )
	MakeBucheRow( false, LogYPlace )
	MakeBucheRow( true, LogYPlace * 2 )
	MakeBucheRow( false, LogYPlace * 3 )
	MakeBucheRow( true, LogYPlace * 4 )
	MakeBucheRow( false, LogYPlace * 5 )
	object{ WoodBarrier translate < -StereLength - 0.7, -LogYPlace, 1 > }
	object{ WoodBarrier translate < -StereLength - 0.7, -LogYPlace, WoodLogLength - 1 > }
	object{ WoodBarrier translate < StereLength + 0.7, -LogYPlace, 1 > }
	object{ WoodBarrier translate < StereLength + 0.7, -LogYPlace, WoodLogLength - 1 > }
	
	translate LogYPlace * y
}